==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "时段"

, "summary"
: "摘要"

, "Total Timesheets"
: "全部的时间表"

, "Billable Timesheets"
: "记帐的时间表"

, "Total Time"
: "全部时间"

, "Time of Billable Timesheets"
: "记帐时间表的时间"

, "Description"
: "描述"

, "Detail"
: ""

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "导出 ODS"

, "Export as CSV"
: "导出 CSV"

, "Export as ..."
: ""

, "Timesheet, Timesheets"
: [
  "时间表"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""

]
, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "单位"

, "Unit Price"
: "单价"

, "Factor"
: ""

, "Budget"
: "预算"

, "Status"
: "状态"

, "closed"
: "已结清"

, "open"
: "打开"

, "Cleared In"
: "已清除于"

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: "记帐的时间表"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "时间帐户"

]
, "Number"
: "号码"

, "Title"
: "头衔"

, "Access"
: "访问"

, "Permissions"
: "许可"

, "Time Account - Billed"
: ""

, "not yet billed"
: "还没记帐"

, "to bill"
: "记帐"

, "billed"
: "已记帐"

, "Time Account - Status"
: "时间帐户－状态"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""

]
, "Book Own"
: "预定自己的"

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "浏览所有的"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: "预定所有的"

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: "管理清除"

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""

]
, "Favorite"
: ""

, "Show closed"
: "关闭展示"

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: ""

, "last week"
: ""

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "已清除于"

, "Billed"
: "已记帐"

, "Booking deadline"
: ""

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "帐户"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "记帐"

, "Cleared"
: "已清除"

, "Date"
: "日期"

, "Start time"
: "开始时间"

, "End time"
: ""

, "Duration"
: "期间"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "时间帐户关闭"

, "Timetracker"
: "时间跟踪器"

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Manage timeaccounts"
: "管理时间帐户"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""






, "Timesheet"
: "时间表"

, "Timeaccount"
: ""

, "Time Account"
: "时间帐户"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Timetracker/js/Timetracker-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "时段"

, "summary"
: "摘要"

, "Total Timesheets"
: "全部的时间表"

, "Billable Timesheets"
: "记帐的时间表"

, "Total Time"
: "全部时间"

, "Time of Billable Timesheets"
: "记帐时间表的时间"

, "Description"
: "描述"

, "Detail"
: ""

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "导出 ODS"

, "Export as CSV"
: "导出 CSV"

, "Export as ..."
: ""

, "Timesheet, Timesheets"
: [
  "时间表"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""

]
, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "单位"

, "Unit Price"
: "单价"

, "Factor"
: ""

, "Budget"
: "预算"

, "Status"
: "状态"

, "closed"
: "已结清"

, "open"
: "打开"

, "Cleared In"
: "已清除于"

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: "记帐的时间表"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "时间帐户"

]
, "Number"
: "号码"

, "Title"
: "头衔"

, "Access"
: "访问"

, "Permissions"
: "许可"

, "Time Account - Billed"
: ""

, "not yet billed"
: "还没记帐"

, "to bill"
: "记帐"

, "billed"
: "已记帐"

, "Time Account - Status"
: "时间帐户－状态"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""

]
, "Book Own"
: "预定自己的"

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "浏览所有的"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: "预定所有的"

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: "管理清除"

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""

]
, "Favorite"
: ""

, "Show closed"
: "关闭展示"

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: ""

, "last week"
: ""

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "已清除于"

, "Billed"
: "已记帐"

, "Booking deadline"
: ""

, "Accounting time factor"
: ""

, "Stream"
: ""

, "hour"
: ""

, "Account"
: "帐户"

, "Time Account (Number - Title)"
: ""

, "Project time billable"
: ""

, "Project time billable (combined)"
: ""

, "Billable"
: "记帐"

, "Project time cleared in"
: ""

, "Project time Invoice"
: ""

, "Project time is cleared"
: ""

, "Projecttime cleared (combined)"
: ""

, "Date"
: "日期"

, "Start time"
: "开始时间"

, "End time"
: ""

, "Duration"
: "期间"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Timetracker"
: "时间跟踪器"

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "Manage timeaccounts"
: "管理时间帐户"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""








, "Timesheet"
: "时间表"

, "Timeaccount"
: ""

, "Time Account"
: "时间帐户"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
